==> openGion6.9.9.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE17S.sql <==
/****************************************************************************/
/* GE17 ( URL転送ﾃｰﾌﾞﾙ )                                                    */
/*                                                                          */
/* Created : 2018/03/29 14:26:08                                            */
/****************************************************************************/

CREATE TABLE GE17 (
   SYSTEM_ID    VARCHAR2 (   10 )                           NOT NULL            /*  10 ｼｽﾃﾑID   */
 , RANDOM_KEY   VARCHAR2 (   32 )                           NOT NULL            /*  20 ﾗﾝﾀﾞﾑｷｰ  */
 , NAME_JA      VARCHAR2 (  200 )                                               /*  30 名称     */
 , DYVALID      VARCHAR2 (    8 )       DEFAULT '99999999'  NOT NULL            /*  40 有効日   */
 , REDIRECT_URL VARCHAR2 ( 4000 )                           NOT NULL            /*  50 転送URL  */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0           NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (   14 )                                               /* 820 登録日時 */
 , PGSET        VARCHAR2 (   10 )                                               /* 830 作成PG   */
 , PGPSET       VARCHAR2 (   10 )                                               /* 840 作成親PG */
 , USRSET       VARCHAR2 (   10 )                                               /* 850 作成社員 */
 , DYUPD        VARCHAR2 (   14 )                                               /* 860 更新日時 */
 , PGUPD        VARCHAR2 (   10 )                                               /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (   10 )                                               /* 880 更新親PG */
 , USRUPD       VARCHAR2 (   10 )                                               /* 890 更新者   */
)
TABLESPACE GETBL01;


CREATE SEQUENCE GE17S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE17T00 
  BEFORE INSERT ON GE17
  FOR EACH ROW 
  BEGIN 
    SELECT GE17S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE17S.sql <==
/****************************************************************************/
/* GE17 ( URL転送ﾃｰﾌﾞﾙ )                                                    */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE17 (
   SYSTEM_ID    VARCHAR2 (   10 )                           NOT NULL            /*  10 ｼｽﾃﾑID   */
 , RANDOM_KEY   VARCHAR2 (   32 )                           NOT NULL            /*  20 ﾗﾝﾀﾞﾑｷｰ  */
 , NAME_JA      VARCHAR2 (  200 )                                               /*  30 名称     */
 , DYVALID      VARCHAR2 (    8 )       DEFAULT '99999999'  NOT NULL            /*  40 有効日   */
 , REDIRECT_URL VARCHAR2 ( 4000 )                           NOT NULL            /*  50 転送URL  */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0           NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (   14 )                                               /* 820 登録日時 */
 , PGSET        VARCHAR2 (   10 )                                               /* 830 作成PG   */
 , PGPSET       VARCHAR2 (   10 )                                               /* 840 作成親PG */
 , USRSET       VARCHAR2 (   10 )                                               /* 850 作成者   */
 , DYUPD        VARCHAR2 (   14 )                                               /* 860 更新日時 */
 , PGUPD        VARCHAR2 (   10 )                                               /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (   10 )                                               /* 880 更新親PG */
 , USRUPD       VARCHAR2 (   10 )                                               /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE17S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE17T00 
  BEFORE INSERT ON GE17
  FOR EACH ROW 
  BEGIN 
    SELECT GE17S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
